"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pageWithPermissions = void 0;
// A HighOrderComponent to host the logic we need in order to achieve permissions tracking for an element.
var router_1 = require("next/router");
var react_1 = __importDefault(require("react"));
var enums_1 = require("../interfaces/enums");
var elementWithPermissions = function (Component, state) {
    var Permissions = function () {
        var _a;
        // Login data added to props via redux-store (or use react context for example)
        if (!state.userData)
            return react_1.default.createElement(react_1.default.Fragment, null);
        if (!state.userData.permissions)
            return react_1.default.createElement(react_1.default.Fragment, null);
        var hasPermissions = !!state.userData && state.userData.permissions.length > 0;
        var isAdmin = ((_a = state.userData) === null || _a === void 0 ? void 0 : _a.permissions[0].permission) === "superAdmin";
        if (!hasPermissions || !isAdmin)
            return react_1.default.createElement(react_1.default.Fragment, null);
        // If user is logged in, return original component
        return react_1.default.createElement(Component, null);
    };
    return Permissions;
};
var pageWithPermissions = function (Component, state) {
    var PagePermissions = function () {
        var _a, _b;
        var router = (0, router_1.useRouter)();
        var isWindowDefined = typeof window !== "undefined";
        // If user is not logged in, return an empty component and push to login page
        if (!state.userData && isWindowDefined) {
            router.push(enums_1.Redirects.BAD_USER_DATA);
            return react_1.default.createElement(react_1.default.Fragment, null);
        }
        if (!((_a = state.userData) === null || _a === void 0 ? void 0 : _a.permissions))
            return react_1.default.createElement(react_1.default.Fragment, null);
        var hasPermissions = !!state.userData && state.userData.permissions.length > 0;
        var isAdmin = ((_b = state.userData) === null || _b === void 0 ? void 0 : _b.permissions[0].permission) === "superAdmin";
        if (!hasPermissions || !isAdmin) {
            if (typeof window !== undefined && router.isReady) {
                router.push(enums_1.Redirects.NOT_FOUND);
            }
            return react_1.default.createElement(react_1.default.Fragment, null);
        }
        // If user is logged in, return original component
        return react_1.default.createElement(Component, null);
    };
    // Copy getInitial props so it will run as well
    if (Component.getInitialProps) {
        PagePermissions.getInitialProps = Component.getInitialProps;
    }
    return PagePermissions;
};
exports.pageWithPermissions = pageWithPermissions;
exports.default = elementWithPermissions;
